#!/bin/bash

URL="https://libregit.org/heckyel/i3-config.git"

while true
do
    function _copy_i3_config() {
        ## Install dependencies
        if [[ $(command -v pacman) ]]; then
            sudo pacman -Syy
            # i3 base
            sudo pacman -S i3-wm i3status dmenu sysstat
            # i3 blocks and dependecies
            sudo pacman -S i3blocks i3lock rofi termite dunst conky playerctl acpi network-manager-applet scrot xfce4-terminal thunar tumbler feh ranger
        elif [[ $(command -v apt-get) ]]; then
            sudo apt update
            # i3 base
            sudo apt install i3-wm i3status suckless-tools sysstat
            # i3 blocks and dependecies
            sudo apt install i3blocks i3lock rofi termite dunst conky playerctl acpi network-manager-applet scrot xfce4-terminal thunar tumbler feh ranger
        fi

        # Install i3config
        printf '\e[1;32m%s\e[1;36m%s\e[m\n' '=> ' 'cloning i3config'
        git clone "$URL" "/tmp/i3config/" --depth=1

        printf '\e[1;32m%s\e[1;36m%s\e[m\n' '=> ' 'copying images'
        cp -rv /tmp/i3config/images "$HOME/.config/i3/"

        printf '\e[1;32m%s\e[1;36m%s\e[m\n' '=> ' 'copying scripts'
        cp -rv /tmp/i3config/scripts "$HOME/.config/i3/"

        printf '\e[1;32m%s\e[1;36m%s\e[m\n' '=> ' 'copying i3 config'
        cp -rv /tmp/i3config/{config,i3blocks.conf} "$HOME/.config/i3/"

        printf '\e[1;32m%s\e[1;36m%s\e[m\n' '=> ' 'copying conky'
        install -m644 -v /tmp/i3config/tmp/conky.conf "$HOME/.config/conky/"

        printf '\e[1;32m%s\e[1;36m%s\e[m\n' '=> ' 'copying fontawesome'
        install -m644 -v /tmp/i3config/tmp/fontawesome.ttf "$HOME/.local/share/fonts/"

        # clean up temp files
        rm -rf /tmp/i3config/
    }

    case  ${LANG/_*/} in
        es)
            read -r -p "¿Estás seguro de instalar i3config? [S/n]: " input
            case $input in
                [sS]|"") _copy_i3_config "$@"; break ;;
                [nN]) break ;;
                *) echo "Por favor responde sí o no" ;;
            esac
            ;;
        *)
            read -r -p "Are you sure to install i3config? [Y/n]: " input
            case $input in
                [yY]|"") _copy_i3_config "$@"; break ;;
                [nN]) break ;;
                *) echo "Please answer yes or no.";;
            esac
            ;;
    esac
done
